@@ -178,6 +178,7 @@ def send_sms():
             # decodage du message
             msg_doc = document['json']['message']
             z = msg_doc.replace("’", "'")
+            z = msg_doc.replace("`", "'")
             msg_doc = unicodedata.normalize('NFKD', z)
             msg_doc = msg_doc.encode('ascii', 'ignore')
             msg_doc = msg_doc.decode()
@@ -452,7 +453,7 @@ def connect_sms(uuid):
 
 
 def define_sender_id(msisdn, smpp, user):
-    telma = (msisdn[-9:]).startswith("34")
+    telma = (msisdn[-9:]).startswith("34") or (msisdn[-9:]).startswith("38")
     # if smpp == "mfs":
     #     sender_id = "mfs"
     if telma:
